<?php

namespace Teknisa\CADFIS\Factories;

use Doctrine\ORM\EntityManager;

class Ger00250ParametrizacaoInscricaoEstadualFactory {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager    = $entityManager;
        $this->connection       = $entityManager->getConnection();
    }
    
    public function selectALIQINTPRODIE_PROD($cdempresa, $cdinscesta, $cdproduto, $nrorg){
        try {
            $sql = "SELECT * FROM ALIQINTPRODIE 
                        WHERE CDEMPRESA = :CDEMPRESA
                        AND CDINSCESTA = :CDINSCESTA 
                        AND CDPRODUTO = :CDPRODUTO
                        AND NRORG = :NRORG";

            $params = array(
                'CDEMPRESA'=>$cdempresa,
                'CDINSCESTA'=>$cdinscesta,
                'CDPRODUTO'=>$cdproduto,
                'NRORG'=>$nrorg
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
            
        }catch (\Exception $e) {
            throw $e;
        }
    } 
    
    public function selectALIQINTPRODIE($cdempresa, $cdinscesta, $nrorg){
        try {
            $sql = "SELECT * FROM ALIQINTPRODIE 
                        WHERE CDEMPRESA = :CDEMPRESA
                        AND CDINSCESTA = :CDINSCESTA 
                        AND NRORG = :NRORG";

            $params = array(
                'CDEMPRESA'=>$cdempresa,
                'CDINSCESTA'=>$cdinscesta,
                'NRORG'=>$nrorg
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
            
        }catch (\Exception $e) {
            throw $e;
        }
    } 
    
    public function insertALIQINTPRODIE($nrseqaliqint, $cdempresa, $cdinscesta, $cdproduto, $vraliqint, $vraliqfecp, $nrorg, $data, $cdoperador){
        try {
            $sql = "INSERT INTO ALIQINTPRODIE 
                               (
                                NRSEQALIQINT, CDEMPRESA, CDINSCESTA, CDPRODUTO, VRALIQINT, VRALIQFECP, NRORG, IDATIVO, DTINCLUSAO, 
                                DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU
                                ) VALUES ( 
                                        :NRSEQALIQINT, 
                                        :CDEMPRESA, 
                                        :CDINSCESTA, 
                                        :CDPRODUTO, 
                                        :VRALIQINT, 
                                        :VRALIQFECP, 
                                        :NRORG,
                                        :IDATIVO,
                                        :DTINCLUSAO,
                                        :DTULTATU,
                                        :NRORGINCLUSAO,
                                        :CDOPERINCLUSAO,
                                        :NRORGULTATU,
                                        :CDOPERULTATU
                                    )";
            

                                 
            $params = array(
                'NRSEQALIQINT'=>$nrseqaliqint,
                'CDEMPRESA'=>$cdempresa,
                'CDINSCESTA'=>$cdinscesta,
                'CDPRODUTO'=>$cdproduto,
                'VRALIQINT'=>$vraliqint,
                'VRALIQFECP'=>$vraliqfecp,
                'NRORG'=>$nrorg,
                'IDATIVO'=>'S',
                'DTINCLUSAO'=>$data,
                'DTULTATU'=>$data,
                'NRORGINCLUSAO'=>$nrorg,
                'CDOPERINCLUSAO'=>$cdoperador,
                'NRORGULTATU'=>$nrorg,
                'CDOPERULTATU'=>$cdoperador,
            );
            $std = $this->connection->prepare($sql);
            $result = $std->execute($params);
            return $result;
            
        }catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function updateALIQINTPRODIE($cdempresa, $cdinscesta, $cdproduto, $vraliqint, $vraliqfecp, $nrorg){
        try {
            $sql = "UPDATE ALIQINTPRODIE
                          SET VRALIQINT = :VRALIQINT,
                            VRALIQFECP = :VRALIQFECP

                        WHERE (CDPRODUTO = :CDPRODUTO)
                            AND (CDEMPRESA = :CDEMPRESA)
                            AND (CDINSCESTA = :CDINSCESTA)
                            AND (NRORG = :NRORG) ";
                            
            $params = array(
                'CDEMPRESA'=>$cdempresa,
                'CDINSCESTA'=>$cdinscesta,
                'CDPRODUTO'=>$cdproduto,
                'VRALIQINT'=>$vraliqint,
                'VRALIQFECP'=>$vraliqfecp,
                'NRORG'=>$nrorg
            );
            $std = $this->connection->prepare($sql);
            $update = $std->execute($params);
            return $update;
            
        }catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getMaxNRSEQALIQINT() {
        try {
            $sql = "SELECT MAX(NRSEQALIQINT) AS NRSEQALIQINT FROM ALIQINTPRODIE";

            $std = $this->connection->prepare($sql);
            $std->execute();
            return $std->fetch();
            
        }catch (\Exception $e) {
            throw $e;
        }
    }
    
// IDATIVO        NOT NULL VARCHAR2(1)  
// DTINCLUSAO              DATE         
// DTULTATU                DATE         
// NRORGINCLUSAO           NUMBER       
// CDOPERINCLUSAO          VARCHAR2(12) 
// NRORGULTATU             NUMBER       
// CDOPERULTATU            VARCHAR2(12) 
    
    public function selectProdCadastAutom($row){
        try {
            $sql = "SELECT DISTINCT
                        PR.CDPRODUTO,
                        PR.NMPRODUTO,
                        PR.CDARVPROD
                        FROM
                            PRODFILI PF,
                            PRODUTO PR
                        WHERE
                            PF.CDPRODUTO = PR.CDPRODUTO
                            AND PR.CDPRODUTO = PR.CDPRODESTO
                            AND (PR.CDARVPROD BETWEEN :CDPRODINI AND :CDPRODFIN)";

            $params = array(
                'CDPRODINI'=>$row['CDARVPRODINI'],
                'CDPRODFIN'=>$row['CDARVPRODFIN']
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            return $std->fetchAll();
            
        }catch (\Exception $e) {
            throw $e;
        }
    } 
    
    public function getproduto($row){
        try {
            $sql = "SELECT 
                        CDPRODUTO
                        FROM
                            PRODUTO 
                        WHERE
                            CDARVPROD = :CDARVPROD";

            $params = array(
                'CDARVPROD'=>$row['CDARVPROD']
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
           
           
            return $std->fetchAll();
            
        }catch (\Exception $e) {
            throw $e;
        }
    } 
    
    
    
  //  INSERT INTO CREDPRESPRODUTO (CDEMPRESA, CDINSCESTA, CDARVPROD, CDPRODUTO, VRALIQINTCONT, VRALIQINTECONT, VRALIQINTNCONT, VRALIQINTENCONT, NRORG, DSOUTROSCRED) VALUES (CDEMPRESA, CDINSCESTA, CDARVPROD, CDPRODUTO, VRALIQINTCONT, VRALIQINTECONT, VRALIQINTNCONT, VRALIQINTENCONT, NRORG, DSOUTROSCRED)
}